@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 
+from django_clear_memcache import _
+
+
 try:
     # try to use AppConfig from Django 1.7, silently ignore on older versions
     from django.apps import AppConfig
-    from django.utils.translation import ugettext_lazy as _
 except ImportError:
     pass
 else:
